@@ -99,8 +99,9 @@ mapdist <- function(from, to, mode = c('driving','walking','bicycling'),
   
     # distance lookup
     if(messaging) message('trying url ', url_string)
-    tree <- fromJSON(paste(readLines(url(url_string)), collapse = ''))
-    closeAllConnections()      
+    connect <- url(url_string)    
+    tree <- fromJSON(paste(readLines(connect), collapse = ''))
+    close(connect)
     
     # label destinations
     names( tree$rows[[1]][[1]] ) <- df$to
